@@ -5,7 +5,7 @@ use base 'PDF::API2::Basic::PDF::Pages';
 use strict;
 use warnings;
 
-our $VERSION = '2.043'; # VERSION
+our $VERSION = '2.044'; # VERSION
 
 use Carp;
 use POSIX qw(floor);
@@ -165,8 +165,8 @@ sub size {
     %boundaries = $page->boundaries();
     ($x1, $y1, $x2, $y2) = $page->boundaries('trim');
 
-Set prepress page boundaries when called with a hash containing one or more page
-boundary definitions.  Returns the C<$page> object.
+Set or replace all prepress page boundaries when called with a hash containing
+one or more page boundary definitions.  Returns the C<$page> object.
 
 Returns the current page boundaries if called without arguments.  Returns the
 coordinates for the specified page boundary if called with one argument.
@@ -377,8 +377,6 @@ sub boundaries {
         $boxes{$box} = [@rectangle];
     }
 
-    # Get
-
     return $self;
 }
 
